#include <array.au3>
#include-once

; ------------------------------------------------------------------------------
;
; AutoIt Version: 3.0
; Language:       English
; Description:    Functions that assist with Image Search
;                 Require that the ImageSearchDLL.dll be loadable
;
; Updated from this link : http://www.autoitscript.com/forum/topic/65748-image-search-library/page__view__findpost__p__797411
;
; ------------------------------------------------------------------------------

;===============================================================================
; Description:      Searches for the specified template contained in an image
;
; Syntax:           _ImageSearch
; Parameters:
;                   $file        - the .BMP file containing the template to look for
;                   $x1          - leftmost coordinate of the search area
;                   $y1          - topmost coordinate of the search area
;                   $x2          - rightmost coordinate of the search area
;                   $y2          - bottommost coordinate of the search area
;                   $transparent - "TRANSBLACK" or "TRANSWHITE", including the '"'
;                                  for hex values, use e.g. "TRANS00FF00"
;                   $variation   - 0 to 255. Used when real colors differ a bit from
;                                  what is used in the template
;                   $runs        - how often the template should be looked for until a result
;                                  is returned; depends on $behavior
;                   $behavior    - 0 = exit on any find
;                                  1 = exit on first positive find
;                                  2 = exit after $runs consecutive finds
;
;
; Return Values:  success - Returns an array of the coordinate set found
;                           $array[1] & $array[2] = coordinate set of the top / left position where the template was found
;                           $array[3] & $array[4] = coordinate set of the center of where the template was found
;
;                 failure - Returns string 0
;===============================================================================
Func _Imagesearch($file, $x1 = 0, $y1 = 0, $x2 = @DesktopWidth, $y2 = @DesktopHeight, $trans = "transblack", $variation = 60, $runs = 1, $behavior = 1)
    If $behavior > 3 Or $behavior < 0 Then $behavior = 1
    If $runs < 1 Or $behavior = 0 Then $runs = 1
    Dim $aCoords[$runs] = [99999]; just some number to make the _ArrayMax <-> _ArrayMin comparison work on it's first run
    $findImage = '*' & $trans & ' ' & '*' & $variation & ' ' & $file & ".bmp"
    $dll = DllOpen("imagesearchdll.dll")
    While 1
        $result = DllCall($dll, "str", "ImageSearch", "int", $x1, "int", $y1, "int", $x2, "int", $y2, "str", $findImage)
        If $result[0] = "0" Then
            _ArrayPush($aCoords, 0, 1)
        Else
            _ArrayPush($aCoords, 1, 1)
            If $behavior = 1 Then ExitLoop
        EndIf
        If _ArrayMax($aCoords) == _ArrayMin($aCoords) Then ExitLoop
        Sleep(40)
    WEnd
    DllClose($dll)
    If $aCoords[0] = 1 Then
        $array = StringSplit($result[0], "|")
        Dim $aCoords[5] = [4, Int(Number($array[2])), Int(Number($array[3])), Int(Number($array[2])) + Int(Number($array[4]) / 2), Int(Number($array[3])) + Int(Number($array[5]) / 2)]
        Return ($aCoords)
    Else
        Return (0)
    EndIf
EndFunc   ;==>_Imagesearch
